@@ -1015,16 +1015,16 @@ spT.validation <- function(z, zhat)
     round(sum(u^2)/sum(v^2), 4)
  }
  ##
- cat("##\n Mean Squared Error (MSE) \n Root Mean Squared Error (RMSE) \n Mean Absolute Error (MAE) \n Mean Absolute Percentage Error (MAPE) \n Bias (BIAS) \n Relative Bias (rBIAS) \n Relative Mean Separation (rMSEP)\n##\n") 
+ #cat("##\n Mean Squared Error (MSE) \n Root Mean Squared Error (RMSE) \n Mean Absolute Error (MAE) \n Mean Absolute Percentage Error (MAPE) \n Bias (BIAS) \n Relative Bias (rBIAS) \n Relative Mean Separation (rMSEP)\n##\n") 
  ##
    out<-NULL
-   out$MSE<-VMSE(c(z), c(zhat))
-   out$RMSE<-RMSE(c(z), c(zhat))
-   out$MAE<-MAE(c(z), c(zhat))
-   out$MAPE<-MAPE(c(z), c(zhat))
-   out$BIAS<-BIAS(c(z), c(zhat))
-   out$rBIAS<-rBIAS(c(z), c(zhat))
-   out$rMSEP<-rMSEP(c(z), c(zhat))
+   out$VMSE<-VMSE(z, zhat)
+   out$RMSE<-RMSE(z, zhat)
+   out$MAE<-MAE(z, zhat)
+   #out$MAPE<-MAPE(z, zhat)
+   #out$BIAS<-BIAS(z, zhat)
+   out$rBIAS<-rBIAS(z, zhat)
+   out$rMSEP<-rMSEP(z, zhat)
    unlist(out)
 }
 ##
@@ -1191,20 +1191,23 @@ model.matrix.spT<-function(object, ...){
 ##
 ## use of summary
 ##
-summary.spT<-function(object, pack="spTimer", ...){
-   if(pack=="coda"){
+summary.spT<-function(object, digits=4, package="spTimer", ...){
+   if(package=="coda"){
     if(object$combined.fit.pred==TRUE){
       stop("\n# Error: coda package is not useful for output with combined fit and predict \n")
     }
     else{
-     cat("\n#### MCMC summary statistics using coda package ####\n")
+     cat("\n#### MCMC summary statistics using coda package ####\n\n")
      tmp<-as.mcmc(object)
-     summary(tmp)
+     summary(tmp, ...)
     }
    }
    else{
+   print(object)
+   cat("-----------------------------------------------------"); cat('\n');
    cat("Parameters:\n")
-   print(object$parameter); #cat("\n");
+   print(round(object$parameter,digits=digits)); #cat("\n");
+   cat("-----------------------------------------------------"); cat('\n');
    }
 }
 ##
@@ -1222,7 +1225,7 @@ plot.spT<-function(x, residuals=FALSE, ...){
      }
      else{
       tmp<-as.mcmc(x)
-      plot(tmp)
+      plot(tmp, ...)
      } 
    }
    else{
@@ -1234,8 +1237,8 @@ plot.spT<-function(x, residuals=FALSE, ...){
 ##
 ## use of coefficients
 ##
-coef.spT<-function(object, ...){
-   t(object$parameter)[1,]
+coef.spT<-function(object, digits=4, ...){
+   round(t(object$parameter)[1,],digits=digits)
 }
 ##
 ## use of residuals
@@ -1274,10 +1277,49 @@ terms.spT<-function(x, ...){
   terms(x$call)
 }
 ##
+## print
+##
+print.spT<-function(x, ...) {
+    cat("-----------------------------------------------------"); cat('\n');
+    cat("Model: "); cat(x$model); cat('\n');
+    cat("Call: "); print(x$call); #cat('\n')
+    cat("Iterations: "); cat(x$iterations); cat("\n")
+    cat("nBurn: "); cat(x$nBurn); cat("\n")
+    cat("Acceptance rate for phi (%): "); cat(x$accept); cat("\n")
+    cat("-----------------------------------------------------"); cat('\n');
+    #cat("PMCC: "); cat("\n");
+    print(x$PMCC); 
+    cat("-----------------------------------------------------"); cat('\n');
+    #cat("Parameters:\n")
+    #print(x$parameter); #cat("\n");
+    #cat("-----------------------------------------------------"); cat('\n');
+    cat("Computation time: "); cat(x$computation.time); cat("\n")
+}
+##
+## use of package forecast
+##
+as.forecast.object<-function(object, site=1, level=c(80,95), ...){
+   # object is the output from the predict.spT for forecast
+   x<-NULL
+   x$model<-list(Name = object$model)
+   x$method<-paste(object$model,"spatio-temporal model, site:",site)
+   x$x<-ts(object$obsData)[,site]
+   x$fitted<-ts(object$fittedData)[,site]
+   x$residuals<-ts(object$residuals)[,site]
+   x$mean<-ts(object$Mean,start=c(dim(object$obsData)[[1]]+1,1))[,site]
+   x$level<-level
+   x$upper<-array(apply(object$fore.samples,1,quantile,probs=c(level/100)),dim=c(length(level),dim(object$Mean)[[1]],dim(object$Mean)[[2]]))
+   x$upper<-t(x$upper[,,site])
+   x$lower<-array(apply(object$fore.samples,1,quantile,probs=c(1-level/100)),dim=c(length(level),dim(object$Mean)[[1]],dim(object$Mean)[[2]]))
+   x$lower<-t(x$lower[,,site])
+   cat(paste("Forecast for site:",site),"\n")
+   class(x)<-"forecast"
+   x
+}
+##
 ## use of display
 ##
 
-
 ##
 ## use of offset
 ##
